"""" Gallagher Python idiomatic client

 Copyight (c) 2023, Anomaly Software Pty Ltd

 This project is **NOT** officially affiliated with Gallagher Security.

 Distributed under the terms of the MIT License.
"""

__version__ = "0.1.0-alpha.4"
