"""


"""

from .access_group import (
    AccessGroupDetail,
)

from .alarm import (
    AlarmDetail,
)

from .card_type import (
    CardTypeDetail,
)

from .cardholder import (
    CardholderDetail,
)

from .discover import (
    FeaturesDetail,
)

from .division import (
    DivisionDetail,
)

from .event import (
    EventDetail,
)

from .pdf import (
    PdfDetail,
)

from .role import (
    RoleDetail,
)
