""" Data Transfer Object

This package defines the data transfer objects (DTOs) to parse
the data from the Gallagher API into Python objects.

We use pyndatic to define the DTOs. pydantic is able to validate
the data types and values of the DTOs.

Our ultimate aim is define rules as outlined by their documentation.

Resources:
  - https://bit.ly/3UkhQhS
  
"""
