""" Locker groups """

from ..utils import (
    AppBaseModel,
    IdentityMixin,
    HrefMixin,
    OptionalHrefMixin,
)


class CardholderLockerSummary(
    AppBaseModel,
    IdentityMixin,
    HrefMixin,
):
    """
    """
    pass

